@@ -1,4 +1,3 @@
-import sys
 import os
 
 
@@ -13,7 +12,7 @@ def read_version():
 __version__, version_date = read_version()
 
 
-def get_version():
+def get_version_string():
     format_str = "nextcode-cli/{version} ({version_date})"
     version_msg = format_str.format(version=__version__, version_date=version_date)
     return version_msg
