@@ -102,12 +102,18 @@ def edit(ctx):
     '-d', '--domain', prompt="Domain name of the service (f.ex. platform.wuxinextcodedev.com)"
 )
 @click.option('-k', '--api-key', help="API Key (if not set a browser will open)")
+@click.option('-r', '--replace', is_flag=True, default=False, help="Replace an existing profile")
 @click.pass_context
-def add(ctx, profile, domain, api_key):
+def add(ctx, profile, domain, api_key, replace):
     """Creates a new profile of the specified name and allows you to configure it"""
     profile = profile.lower()
-    if profile in get_profiles():
-        click.secho("Profile '%s' already exists. Did you mean to 'edit' it?" % profile, fg='red')
+    if profile in get_profiles() and not replace:
+        click.secho(
+            "Profile '%s' already exists. Use --replace if you want to override it.".format(
+                profile
+            ),
+            fg='red',
+        )
         return
 
     # check for common mistakes in domain name
@@ -127,7 +133,9 @@ def add(ctx, profile, domain, api_key):
                 return
 
         if reachable:
-            click.echo("Launching login webpage {} ==> Please retrieve API Key from browser".format(url))
+            click.echo(
+                "Launching login webpage {} ==> Please retrieve API Key from browser".format(url)
+            )
             click.launch(url)
             click.pause()
         else:
