@@ -20,6 +20,8 @@ def cli(ctx):
     if ctx.obj.service is None:
         check_profile(ctx)
         ctx.obj.service = ctx.obj.client.service("workflow")
+        ctx.obj.session = ctx.obj.service.session
+        ctx.obj.job = None
 
 
 from nextcodecli.commands.workflow.jobs import jobs
