@@ -7,12 +7,9 @@ import logging
 import os
 import sys
 import json
-import click
-from jsonpath_rw import jsonpath, parse
+from jsonpath_rw import parse
 import yaml
 
-from nextcode.exceptions import ServerError
-
 log_formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s')
 
 console_handler = logging.StreamHandler()
@@ -147,6 +144,4 @@ def abort(reason, code=1):
 
 def check_profile(ctx):
     if not ctx.obj.client:
-        abort(
-            "You have no active profile or selected profile is invalid."
-        )
+        abort("You have no active profile or selected profile is invalid.")
